@@ -2,7 +2,7 @@ package Geo::Coder::Google::V3;
 
 use strict;
 use warnings;
-our $VERSION = '0.11_02';
+our $VERSION = '0.11_03';
 
 use Carp;
 use Encode;
@@ -85,13 +85,7 @@ sub geocode {
     my $json = JSON->new->utf8;
     my $data = $json->decode($res->content);
 
-    if ($data->{status} eq 'OVER_QUERY_LIMIT') {
-        Carp::croak("Google Maps API exceeded query limit");
-    } elsif ($data->{status} eq 'REQUEST_DENIED') {
-        Carp::croak("Google Maps API request denied");
-    } elsif ($data->{status} eq 'INVALID_REQUEST') {
-        Carp::croak("Google Maps API invalid request");
-    }
+    Carp::croak(sprintf "Google Maps API returned status '%s'", $data->{status}) unless $data->{status} eq 'OK';
 
     my @results = @{ $data->{results} || [] };
     wantarray ? @results : $results[0];
